SystemdConstants

Struct SystemdConstants 

pub struct SystemdConstants;

Implementations

Source

impl SystemdConstants

pub const APP_NAME: &'static str = "systemdls"

pub fn valid_sections() -> Vec<&'static str>

pub fn section_directives() -> HashMap<&'static str, Vec<&'static str>>

pub fn directive_descriptions() -> HashMap<(&'static str, &'static str), &'static str>

pub fn valid_values() -> HashMap<&'static str, &'static [&'static str]>

pub fn valid_values_for_section( section: &str, directive: &str, ) -> Option<&'static [&'static str]>

pub fn section_documentation() -> HashMap<&'static str, &'static str>

pub fn shared_documentation() -> HashMap<&'static str, &'static str>

Get shared documentation files (exec, kill, resource-control) These contain directives that are shared across multiple section types

pub fn section_shared_docs(section: &str) -> Vec<&'static str>

Returns the list of shared documentation keys that apply to a given section This mapping determines which additional directive sets are available in each section